/*******************************************************************************/
/*                                                                             */
/*    Copyright (c) 2007 Analog Devices, Inc.  All Rights Reserved.            */
/*    This software is proprietary to Analog Devices, Inc. and its 			   */
/*	  licensors.                                  							   */
/*                                                                             */
/*    CHANGES:  07/02/2007  1.00  - initial public release  				   */
/*																			   */
/*******************************************************************************/

/*********************************************************************

Include files

*********************************************************************/

#include "main.h"
#include "stdio.h"
#include "system.h"

#define YELLOW	(0xD292D210)		// yellow pixel pattern
#define RED		(0x51F0515A)

#ifdef SEPERATE_BANKS //Place buffers in seperate banks.

	section("sdram_data_bank0") static char Frame[1716 * 525];
	section("sdram_data_bank0") static char sport_Frame[1024];
	section("sdram_data_bank0_1") static char Frame1_1[1716 * 525];

	section("sdram_data_bank1") static char Frame2[1716 * 525];
	section("sdram_data_bank1_1") static char Frame2_1[1716 * 525];

	section("sdram_data_bank2") static char Frame3[1716 * 525];
	section("sdram_data_bank2_1") static char Frame3_1[1716 * 525];

	section("sdram_data_bank3") static char Frame4[1716 * 525];
	section("sdram_data_bank3") static char sport_Frame1[1024];
	section("sdram_data_bank3_1") static char Frame4_1[1716 * 525];
#else

	section("sdram_data_bank0") static char Frame[1716 * 525];
	section("sdram_data_bank0") static char Frame1_1[1716 * 525];
	section("sdram_data_bank0") static char Frame2[1716 * 525];
	section("sdram_data_bank0") static char Frame2_1[1716 * 525];
	section("sdram_data_bank1") static char Frame3[1716 * 525];
	section("sdram_data_bank1") static char Frame3_1[1716 * 525];
	section("sdram_data_bank1") static char Frame4[1716 * 525];
	section("sdram_data_bank1") static char Frame4_1[1716 * 525];
	section("sdram_data_bank0") static char sport_Frame[1024];
	section("sdram_data_bank1") static char sport_Frame1[1024];
#endif

section ("L1_data_a") static char L1buffer[BUFFER_SIZE];
section ("L1_data_a") static char L1buffer2[BUFFER_SIZE];
section ("L1_data_b") static char L1buffer3[BUFFER_SIZE];
section ("L1_data_b") static char L1buffer4[BUFFER_SIZE];

section ("l2_sram") static char L2buffer[BUFFER_SIZE];
section ("l2_sram") static char L2buffer2[BUFFER_SIZE];
section ("l2_sram") static char L2buffer3[BUFFER_SIZE];

tDMA_descriptor DMA_PPI_first = 	{&DMA_PPI_first, Frame4};
tDMA_descriptor DMA_PPI0_first = 	{&DMA_PPI0_first, Frame4};



bool MDMA_Ready=false;
bool Set_PACK32 = false;
bool Set_Entire_Field = false;

/*
	Function: main() 

	Description:Initialize and enable all codecs, peripherals and MDMA 
			 	channels and wait for interrupts
*/
void main()
{
	int i,temp, a;
	
	
	// set Clocks
	Set_PLL( (short)(CORECLK/CLKIN), (short)(CORECLK/SYSCLK));			// sets Core and System Clocks to the values defined in system.h 
	
	//Init SDRAM
	InitSDRAM();
	
	//Init Interrupts	
	InitInterrupts();
		
	//Init PPI DMA
	Init_PPI_DMA(&DMA_PPI_first);
	
	//Init MDMA
	InitMDMA1_CH0(Frame4, L1buffer);
//	InitMDMA1_CH0(L1buffer,Frame4);
	InitMDMA1_CH1(L1buffer3,Frame4);

	Set_PACK32 = false;
	#ifdef PACKENABLE
		Set_PACK32 = true;
	#endif
	
	Set_Entire_Field = false;
	#ifdef ENTIRE_FIELD_MODE
		Set_Entire_Field = true;
	#endif
	
	//Init PPI0
	InitPPI0(Set_Entire_Field, Set_PACK32, &DMA_PPI0_first, PIXEL_PER_LINE, NTSC_NUM_LINES);
	
	//Init PPI1
	InitPPI1(Set_PACK32, &DMA_PPI_first, PIXEL_PER_LINE, NTSC_NUM_LINES);
	
	// initialise Video Encoder ADV7179
	Reset_ADV7179();
	
	// initialise Video Decoder ADV7183
	Reset_ADV7183();
	
	//Fill video buffer with known color pattern. Not necessary but to make sure benchmark running correctly
	NtscVideoOutFrameBuffInit(Frame);
	FillFrame (Frame, RED);
	NtscVideoOutFrameBuffInit(Frame2);
	FillFrame (Frame2, YELLOW);
		
	#ifdef PPI0
		//Enable DMA first and then enable PPI
		EnablePPI0();
	#endif
	
	#ifdef PPI1
		EnablePPI1();
	#endif
	
	//Enable MEMDMA 1 and 2
	#ifdef MEMDMA1_0
		*pMDMA1_S0_CONFIG |=  0x0001;									// ENABLE MDMA
		ssync();
		*pMDMA1_D0_CONFIG |=  0x0001;
		ssync();
	#endif
	
	#ifdef MEMDMA1_1
		*pMDMA1_S1_CONFIG |=  0x0001;									// ENABLE MDMA
		ssync();
		*pMDMA1_D1_CONFIG |=  0x0001;
		ssync();
	#endif
	
	#ifdef SET_TRAFFIC_CONTROL_0x7ff
			*pDMA1_TC_PER =0x7ff;
	#endif

	#ifdef SET_TRAFFIC_CONTROL_0x777
			*pDMA1_TC_PER =0x777;
	#endif

	
	while(1)
	{
			
	};	 //wait for interrupts
}
